==> v0.2.0.zip: syncthingtray/connector/translations/syncthingconnector_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>Data::SyncthingConnection</name>
    <message>
        <location filename="../syncthingconnection.cpp" line="94"/>
        <source>disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="96"/>
        <source>reconnecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="98"/>
        <source>connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="100"/>
        <source>connected, paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="102"/>
        <source>connected, synchronizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="104"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="131"/>
        <location filename="../syncthingconnection.cpp" line="206"/>
        <source>Connection configuration is insufficient.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="576"/>
        <source>Unable to request QR-Code: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="605"/>
        <source>Unable to parse Syncthing log: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="609"/>
        <source>Unable to request system log: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="646"/>
        <source>Unable to locate certificate used by Syncthing GUI.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="652"/>
        <source>Unable to load certificate used by Syncthing GUI.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="714"/>
        <source>Unable to parse Syncthing config: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="720"/>
        <source>Unable to request Syncthing config: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="818"/>
        <source>Unable to parse Syncthing status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="824"/>
        <source>Unable to request Syncthing status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="899"/>
        <source>Unable to parse connections: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="905"/>
        <source>Unable to request connections: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="959"/>
        <source>Unable to parse directory statistics: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="965"/>
        <source>Unable to request directory statistics: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1001"/>
        <source>Unable to parse device statistics: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1007"/>
        <source>Unable to request device statistics: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1045"/>
        <source>Unable to parse errors: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1056"/>
        <source>Unable to request errors: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1109"/>
        <source>Unable to parse Syncthing events: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1131"/>
        <source>Unable to request Syncthing events: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1394"/>
        <source>Unable to request rescan: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1414"/>
        <source>Unable to request pause/resume: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1430"/>
        <source>Unable to request restart: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1446"/>
        <source>Unable to request shutdown: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::Utils</name>
    <message>
        <location filename="../utils.cpp" line="16"/>
        <source>%1 ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="18"/>
        <source>right now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> v0.4.1.zip: syncthingtray/connector/translations/syncthingconnector_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>Data::SyncthingConnection</name>
    <message>
        <location filename="../syncthingconnection.cpp" line="104"/>
        <source>disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="106"/>
        <source>reconnecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="108"/>
        <source>connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="110"/>
        <source>connected, paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="112"/>
        <source>connected, synchronizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="114"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="141"/>
        <location filename="../syncthingconnection.cpp" line="228"/>
        <source>Connection configuration is insufficient.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="608"/>
        <source>Unable to request QR-Code: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="637"/>
        <source>Unable to parse Syncthing log: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="641"/>
        <source>Unable to request Syncthing log: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="675"/>
        <source>Unable to locate certificate used by Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="681"/>
        <source>Unable to load certificate used by Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="766"/>
        <source>Unable to parse Syncthing config: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="772"/>
        <source>Unable to request Syncthing config: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="870"/>
        <source>Unable to parse Syncthing status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="876"/>
        <source>Unable to request Syncthing status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="955"/>
        <source>Unable to parse connections: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="961"/>
        <source>Unable to request connections: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1015"/>
        <source>Unable to parse directory statistics: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1021"/>
        <source>Unable to request directory statistics: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1057"/>
        <source>Unable to parse device statistics: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1063"/>
        <source>Unable to request device statistics: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1101"/>
        <source>Unable to parse errors: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1112"/>
        <source>Unable to request errors: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1128"/>
        <source>Unable to request clearing errors: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1181"/>
        <source>Unable to parse Syncthing events: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1203"/>
        <source>Unable to request Syncthing events: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1466"/>
        <source>Unable to request rescan: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1486"/>
        <source>Unable to request pause/resume: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1502"/>
        <source>Unable to request restart: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1518"/>
        <source>Unable to request shutdown: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingService</name>
    <message>
        <location filename="../syncthingservice.cpp" line="132"/>
        <source>start unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="134"/>
        <source>stop unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="141"/>
        <source>enable unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="143"/>
        <source>disable unit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::Utils</name>
    <message>
        <location filename="../utils.cpp" line="22"/>
        <source>%1 ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="24"/>
        <source>right now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
